==> num-java-module-binding-contacts-0.0.7-sources.jar: uk/num/modules/contacts/expanded/ContactsModule.java <==
package uk.num.modules.contacts.expanded;

import com.fasterxml.jackson.annotation.*;
import java.util.List;

public class ContactsModule {
    private long n;
    private Boolean p;
    private String bio;
    private List<Contact> contacts;
    private String description;
    private String name;
    private String objectDisplayName;
    private String objectType;
    private String role;
    private String slogan;

    @JsonProperty("@n")
    public long getN() { return n; }
    @JsonProperty("@n")
    public void setN(long value) { this.n = value; }

    @JsonProperty("@p")
    public Boolean getP() { return p; }
    @JsonProperty("@p")
    public void setP(Boolean value) { this.p = value; }

    @JsonProperty("bio")
    public String getBio() { return bio; }
    @JsonProperty("bio")
    public void setBio(String value) { this.bio = value; }

    @JsonProperty("contacts")
    public List<Contact> getContacts() { return contacts; }
    @JsonProperty("contacts")
    public void setContacts(List<Contact> value) { this.contacts = value; }

    @JsonProperty("description")
    public String getDescription() { return description; }
    @JsonProperty("description")
    public void setDescription(String value) { this.description = value; }

    @JsonProperty("name")
    public String getName() { return name; }
    @JsonProperty("name")
    public void setName(String value) { this.name = value; }

    @JsonProperty("object_display_name")
    public String getObjectDisplayName() { return objectDisplayName; }
    @JsonProperty("object_display_name")
    public void setObjectDisplayName(String value) { this.objectDisplayName = value; }

    @JsonProperty("object_type")
    public String getObjectType() { return objectType; }
    @JsonProperty("object_type")
    public void setObjectType(String value) { this.objectType = value; }

    @JsonProperty("role")
    public String getRole() { return role; }
    @JsonProperty("role")
    public void setRole(String value) { this.role = value; }

    @JsonProperty("slogan")
    public String getSlogan() { return slogan; }
    @JsonProperty("slogan")
    public void setSlogan(String value) { this.slogan = value; }
}

==> num-java-module-binding-contacts-0.0.10-sources.jar: uk/num/modules/contacts/expanded/ContactsModule.java <==
package uk.num.modules.contacts.expanded;

import com.fasterxml.jackson.annotation.*;
import java.util.List;

public class ContactsModule {
    private long n;
    private Long p;
    private String bio;
    private List<Contact> contacts;
    private String description;
    private String name;
    private String objectDisplayName;
    private String objectType;
    private String role;
    private String slogan;

    @JsonProperty("@n")
    public long getN() { return n; }
    @JsonProperty("@n")
    public void setN(long value) { this.n = value; }

    @JsonProperty("@p")
    public Long getP() { return p; }
    @JsonProperty("@p")
    public void setP(Long value) { this.p = value; }

    @JsonProperty("bio")
    public String getBio() { return bio; }
    @JsonProperty("bio")
    public void setBio(String value) { this.bio = value; }

    @JsonProperty("contacts")
    public List<Contact> getContacts() { return contacts; }
    @JsonProperty("contacts")
    public void setContacts(List<Contact> value) { this.contacts = value; }

    @JsonProperty("description")
    public String getDescription() { return description; }
    @JsonProperty("description")
    public void setDescription(String value) { this.description = value; }

    @JsonProperty("name")
    public String getName() { return name; }
    @JsonProperty("name")
    public void setName(String value) { this.name = value; }

    @JsonProperty("object_display_name")
    public String getObjectDisplayName() { return objectDisplayName; }
    @JsonProperty("object_display_name")
    public void setObjectDisplayName(String value) { this.objectDisplayName = value; }

    @JsonProperty("object_type")
    public String getObjectType() { return objectType; }
    @JsonProperty("object_type")
    public void setObjectType(String value) { this.objectType = value; }

    @JsonProperty("role")
    public String getRole() { return role; }
    @JsonProperty("role")
    public void setRole(String value) { this.role = value; }

    @JsonProperty("slogan")
    public String getSlogan() { return slogan; }
    @JsonProperty("slogan")
    public void setSlogan(String value) { this.slogan = value; }
}
